![Logo](docs/logo.svg)

[![GitHub license](https://img.shields.io/github/license/uktrade/lite-linter.svg)](https://github.com/uktrade/lite-linter/blob/master/LICENSE)

Python library for linting LITE's frontend code.

## Running

For now run it through "python main.py"

It'll eventually be added as a pip dependency and used through CircleCI.
